#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-25RDerzb6xL3h2mBmG2Qw4
key:                  lsp-2.2.0.0-25RDerzb6xL3h2mBmG2Qw4
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  0b06494235808d78c9b57b293582777b
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-DGx1hGDMCQaCt6WtRsllyh:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-DGx1hGDMCQaCt6WtRsllyh:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-DGx1hGDMCQaCt6WtRsllyh:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-DGx1hGDMCQaCt6WtRsllyh:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-25RDerzb6xL3h2mBmG2Qw4
depends:
    aeson-2.2.1.0-5nVyzmxvbxuJpsKX5ABORi
    async-2.2.5-G9iNhoihA4w9hFmxVZ2fQd
    attoparsec-0.14.4-6aADy1PhqXs9BGl4XaO8ak base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-CcbaRQkCR9WKKKCRd1EfmJ
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-T6DCV5EfgDB3vghPWgrCN
    lens-5.3.4-8NFr5J3yyaeHueVQitYA5u
    lens-aeson-1.2.3-BuFiN0MtTC828Nr4yMgtOl
    lsp-types-2.0.2.0-DGx1hGDMCQaCt6WtRsllyh mtl-2.3.1
    prettyprinter-1.7.1-EY3nijkmaHU7AF2RkegSvD
    random-1.2.1.3-2otWecMyOCFLGjlq6igNwD
    row-types-1.0.1.2-7nN8k7lXxMNsV3GZ0L0fp
    sorted-list-0.2.3.1-JD5lBKFrnZI6sowJu85gPJ stm-2.5.1.0
    temporary-1.3-1NBq1jdafNy1CacDIaV1ZS text-2.0.2
    text-rope-0.3-JvT1DvI0y8XEZCPQTQkcke transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-LXAzHO8zZLp8w9V0PnyDcb
    uuid-1.3.16-7DgGWDyj8BqJIp6JY8kGq9

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

